"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fromBase = exports.getUnitByKind = exports.getUnit = exports.as = exports.asImperial = exports.asMetric = exports.userKindOption = exports.setUserKindOption = exports.useMetric = exports.setUseMetric = exports.units = void 0;

var _jsQuantities = _interopRequireDefault(require("js-quantities"));

var _transforms = require("./transforms");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var units = {
  // kind: ['metric', 'imperial', 'option #3', 'option #4', ...]
  length: [{
    name: 'Meters',
    abbv: 'm'
  }, {
    name: 'Feets',
    abbv: 'ft'
  }],
  area: [{
    name: 'Square meters',
    abbv: 'm2'
  }, {
    name: 'Square feets',
    abbv: 'ft2'
  }],
  volume: [{
    name: 'Liters',
    abbv: 'l'
  }, {
    name: 'Fluid-ounces',
    abbv: 'floz'
  }],
  temperature: [{
    name: 'Celsius',
    abbv: 'tempC'
  }, {
    name: 'Fahrenheit',
    abbv: 'tempF'
  }],
  pressure: [{
    name: 'Pascal',
    abbv: 'MPa'
  }, {
    name: 'psi',
    abbv: 'psi'
  }, {
    name: 'Bars',
    abbv: 'bar'
  }]
}; // LocalStorage helpers.

exports.units = units;

var store = function store(obj) {
  return localStorage.setItem('units', JSON.stringify(obj));
};

var load = function load() {
  try {
    return JSON.parse(localStorage.getItem('units')) || {};
  } catch (_unused) {
    return {};
  }
}; // Use metric accessors.


var setUseMetric = function setUseMetric(useMetric) {
  return store(Object.assign(load(), {
    useMetric: useMetric
  }));
};

exports.setUseMetric = setUseMetric;

var useMetric = function useMetric(appConfigUseMetric) {
  var value = load();
  return typeof value.useMetric === 'boolean' ? value.useMetric : appConfigUseMetric;
}; // User kind options accessors.


exports.useMetric = useMetric;

var setUserKindOption = function setUserKindOption(kind, option) {
  var value = load();

  if ((0, _transforms.nilOrEmpty)(option)) {
    if (value.kinds) delete value.kinds[kind];
  } else {
    if (!value.kinds) value.kinds = {};
    value.kinds[kind] = option;
  }

  store(value);
};

exports.setUserKindOption = setUserKindOption;

var userKindOption = function userKindOption(kind) {
  var value = load();
  return value.kinds ? value.kinds[kind] : undefined;
}; // kind -> kind.


exports.userKindOption = userKindOption;

var repKind = function repKind(metric, kind) {
  var toUnit = userKindOption(kind);
  if (toUnit) return toUnit;
  if (units[kind]) return units[kind][metric ? 0 : 1].abbv;
  return undefined;
};

var represent = function represent(metric) {
  return function (val, unit) {
    var q = (0, _jsQuantities["default"])(val, unit);
    var toUnit = repKind(metric, q.kind());
    return toUnit ? q.to(toUnit) : q.toBase();
  };
}; // (value, 'unit') => value.


var asMetric = represent(true);
exports.asMetric = asMetric;
var asImperial = represent(false);
exports.asImperial = asImperial;
var as = represent(useMetric()); // Get user specific unit from unit or kind.

exports.as = as;

var getUnit = function getUnit(fromUnit) {
  return as(1, fromUnit).units();
};

exports.getUnit = getUnit;

var getUnitByKind = function getUnitByKind(kind) {
  return getUnit(_jsQuantities["default"].getUnits(kind)[0]);
}; // From SI units to user specific.


exports.getUnitByKind = getUnitByKind;

var fromBase = function fromBase(value, kind) {
  return as(value, (0, _jsQuantities["default"])(1, _jsQuantities["default"].getUnits(kind)[0]).toBase().units());
};

exports.fromBase = fromBase;